==> humhub-1.17.5.zip: humhub-1.17.5/protected/humhub/messages/bg/base.php <==
<?php

return [
    '<strong>Confirm</strong> Action' => '<strong>Потвърждаване</strong> на Действие',
    '<strong>Latest</strong> updates' => '<strong>Последни</strong> ъпдейти',
    '<strong>Mail</strong> summary' => 'Резюме на <strong>Пощата</strong>',
    'Actions' => 'Действия',
    'Add:' => 'Добави:',
    'Administration' => 'Администрация',
    'All' => 'Всички',
    'Allow' => 'Позволявам',
    'An error occurred while handling your last action. (Handler not found).' => 'При обработката на последното ви действие възникна грешка. (Причината не е намерена).',
    'An unexpected error occurred while loading the search result.' => 'При зареждането на резултата от търсенето възникна неочаквана грешка.',
    'An unexpected error occurred. If this keeps happening, please contact a site administrator.' => 'Възникна неочаквана грешка. Ако това продължава да се случва, моля, свържете се с администратор на сайта.',
    'An unexpected server error occurred. If this keeps happening, please contact a site administrator.' => 'Възникна неочаквана грешка в сървъра. Ако това продължава да се случва, моля, свържете се с администратор на сайта.',
    'Back' => 'Назад',
    'Back to dashboard' => 'Върни се в работното място',
    'Cancel' => 'Отказ',
    'Choose language:' => 'Избери език:',
    'Close' => 'Затваряне',
    'Collapse' => 'Свий',
    'Confirm' => 'Потвърждение',
    'Content Addon source must be instance of HActiveRecordContent or HActiveRecordContentAddon!' => 'Съдържанието на Content Addon трябва да бъде инстанция на HActiveRecordContent или HActiveRecordContentAddon!',
    'Copy to clipboard' => 'Копиране в клипборда',
    'Could not find content of addon!' => 'Не може да се намери съдържанието на addon!',
    'Could not find requested page.' => 'Търсената страница не можа да бъде намерена.',
    'Default' => 'По подразбиране',
    'Delete' => 'Изтрий',
    'Deny' => 'Отказ',
    'Do you really want to perform this action?' => 'Наистина ли искате да извършите това действие?',
    'Edit' => 'Редактиране',
    'Error' => 'Грешка',
    'Error while running your last action (Invalid request method).' => 'Грешка при изпълнение на последното ви действие (невалиден метод на заявка).',
    'Error:' => 'Грешка:',
    'Expand' => 'Разшири',
    'Export' => 'Извличане',
    'Info:' => 'Информация:',
    'Invalid request method!' => 'Невалиден метод на заявката!',
    'It looks like you may have taken the wrong turn.' => 'Изглежда, че може да сте взели грешно действие.',
    'Language' => 'Език',
    'Loading...' => 'Зареждане...',
    'Login' => 'Вход',
    'Logo of {appName}' => 'Лого на {appName}',
    'Logout' => 'Изход',
    'Menu' => 'Меню',
    'Module is not enabled on this content container!' => 'Модулът не е активиран в този content container!',
    'New profile image' => 'Нова профилна картинка',
    'Next' => 'Следващ',
    'No error information given.' => 'Няма информация за грешката.',
    'Oooops...' => 'Опаля...',
    'Open' => 'Отворено',
    'Please type at least 3 characters' => 'Моля, въведете поне 3 знака',
    'Please type at least {count} characters' => 'Моля, въведете поне {count} знака',
    'Powered by {name}' => 'Реализиран от {name}',
    'Profile dropdown' => 'Падащо меню на профил',
    'Profile picture of {displayName}' => 'Профилна снимка на {displayName}',
    'Save' => 'Запази',
    'Saved' => 'Запазено',
    'Search' => 'Търси',
    'Select Me' => 'Избери мен',
    'Settings' => 'Настройки',
    'Show less' => 'Покажи по-малко',
    'Show more' => 'Покажи повече',
    'Some files could not be uploaded:' => 'Някои файлове не можаха да бъдат качени:',
    'Text could not be copied to clipboard' => 'Текстът не може да бъде копиран в клипборда',
    'Text has been copied to clipboard' => 'Текстът не може да бъде копиран в клипборда',
    'The date has to be in the past.' => 'Датата трябва да е в миналото.',
    'The file has been deleted.' => 'Файлът е изтрит.',
    'The requested resource could not be found.' => 'Търсеният ресурс не можа да бъде намерен.',
    'The space has been archived.' => 'Пространството е архивирано.',
    'The space has been unarchived.' => 'Пространството е разархивирано.',
    'Time Zone' => 'Часова зона',
    'Toggle comment menu' => 'Превключване на менюто за коментари',
    'Toggle panel menu' => 'Превключване на менюто на панела',
    'Toggle post menu' => 'Превключване на менюто за публикация',
    'Toggle stream entry menu' => 'Превключване на менюто за въвеждане на данни',
    'Unsaved changes will be lost. Do you want to proceed?' => 'Има незапазени промени, наистина ли искате да напуснете тази страница?',
    'Unsubscribe' => 'Отписване',
    'Upload' => 'Качване',
    'Upload file' => 'Качи файл',
    'You are not allowed to run this action.' => 'Нямате право да изпълнявате това действие.',
    '{nFormatted}B' => '{nFormatted}B',
    '{nFormatted}K' => '{nFormatted}K',
    '{nFormatted}M' => '{nFormatted}M',
    'Allow content from external source' => '',
    'Always allow content from this provider!' => '',
    'An unexpected error occurred. Please check whether your file exceeds the allowed upload limit of {maxUploadSize}.' => '',
    'Do you want to enable content from \'{urlPrefix}\'?' => '',
    'My Profile' => '',
    'No results' => '',
    'Search...' => '',
    'Show all results' => '',
    'Stop impersonation' => '',
    'verify your upload_max_filesize and post_max_size php settings.' => '',
    '{attribute} has been empty. The system-configured function to fill empty values has returned an invalid value. Please try again or contact your administrator.' => '',
    '{attribute} must be a string (UUID) or null; {type} given.' => '',
    '{attribute} must be an UUID or null. UUID has the format "{{XXXXXXXX-XXXX-XXXX-XXXX-XXXXXXXXXXXX}}", where X = [a-fA-F0-9] and both curly brackets and delimiting dashes are optional.' => '',
];

==> humhub-1.18.0.zip: humhub-1.18.0/protected/humhub/messages/bg/base.php <==
<?php

return [
    '<strong>Confirm</strong> Action' => '<strong>Потвърждаване</strong> на Действие',
    '<strong>Latest</strong> updates' => '<strong>Последни</strong> ъпдейти',
    '<strong>Mail</strong> summary' => 'Резюме на <strong>Пощата</strong>',
    'Actions' => 'Действия',
    'Add:' => 'Добави:',
    'Administration' => 'Администрация',
    'All' => 'Всички',
    'Allow' => 'Позволявам',
    'An error occurred while handling your last action. (Handler not found).' => 'При обработката на последното ви действие възникна грешка. (Причината не е намерена).',
    'An unexpected error occurred while loading the search result.' => 'При зареждането на резултата от търсенето възникна неочаквана грешка.',
    'An unexpected error occurred. If this keeps happening, please contact a site administrator.' => 'Възникна неочаквана грешка. Ако това продължава да се случва, моля, свържете се с администратор на сайта.',
    'An unexpected server error occurred. If this keeps happening, please contact a site administrator.' => 'Възникна неочаквана грешка в сървъра. Ако това продължава да се случва, моля, свържете се с администратор на сайта.',
    'Back' => 'Назад',
    'Back to dashboard' => 'Върни се в работното място',
    'Cancel' => 'Отказ',
    'Choose language:' => 'Избери език:',
    'Close' => 'Затваряне',
    'Collapse' => 'Свий',
    'Confirm' => 'Потвърждение',
    'Content Addon source must be instance of ContentActiveRecord or ContentAddonActiveRecord!' => 'Съдържанието на Content Addon трябва да бъде инстанция на ContentActiveRecord или ContentAddonActiveRecord!',
    'Copy to clipboard' => 'Копиране в клипборда',
    'Could not find content of addon!' => 'Не може да се намери съдържанието на addon!',
    'Could not find requested page.' => 'Търсената страница не можа да бъде намерена.',
    'Default' => 'По подразбиране',
    'Delete' => 'Изтрий',
    'Deny' => 'Отказ',
    'Do you really want to perform this action?' => 'Наистина ли искате да извършите това действие?',
    'Edit' => 'Редактиране',
    'Enter security code above' => 'Въведете кода за сигурност по-горе',
    'Error' => 'Грешка',
    'Error while running your last action (Invalid request method).' => 'Грешка при изпълнение на последното ви действие (невалиден метод на заявка).',
    'Error:' => 'Грешка:',
    'Expand' => 'Разшири',
    'Export' => 'Извличане',
    'Info:' => 'Информация:',
    'Invalid request method!' => 'Невалиден метод на заявката!',
    'It looks like you may have taken the wrong turn.' => 'Изглежда, че може да сте взели грешно действие.',
    'Language' => 'Език',
    'Loading...' => 'Зареждане...',
    'Login' => 'Вход',
    'Logo of {appName}' => 'Лого на {appName}',
    'Logout' => 'Изход',
    'Menu' => 'Меню',
    'Module is not enabled on this content container!' => 'Модулът не е активиран в този content container!',
    'New profile image' => 'Нова профилна картинка',
    'Next' => 'Следващ',
    'No error information given.' => 'Няма информация за грешката.',
    'Oooops...' => 'Опаля...',
    'Open' => 'Отворено',
    'Please type at least 3 characters' => 'Моля, въведете поне 3 знака',
    'Please type at least {count} characters' => 'Моля, въведете поне {count} знака',
    'Powered by {name}' => 'Реализиран от {name}',
    'Profile dropdown' => 'Падащо меню на профил',
    'Profile picture of {displayName}' => 'Профилна снимка на {displayName}',
    'Save' => 'Запази',
    'Saved' => 'Запазено',
    'Search' => 'Търси',
    'Select Me' => 'Избери мен',
    'Settings' => 'Настройки',
    'Show less' => 'Покажи по-малко',
    'Show more' => 'Покажи повече',
    'Some files could not be uploaded:' => 'Някои файлове не можаха да бъдат качени:',
    'Text could not be copied to clipboard' => 'Текстът не може да бъде копиран в клипборда',
    'Text has been copied to clipboard' => 'Текстът не може да бъде копиран в клипборда',
    'The date has to be in the past.' => 'Датата трябва да е в миналото.',
    'The file has been deleted.' => 'Файлът е изтрит.',
    'The requested resource could not be found.' => 'Търсеният ресурс не можа да бъде намерен.',
    'The space has been archived.' => 'Пространството е архивирано.',
    'The space has been unarchived.' => 'Пространството е разархивирано.',
    'Time Zone' => 'Часова зона',
    'Toggle comment menu' => 'Превключване на менюто за коментари',
    'Toggle panel menu' => 'Превключване на менюто на панела',
    'Toggle post menu' => 'Превключване на менюто за публикация',
    'Toggle stream entry menu' => 'Превключване на менюто за въвеждане на данни',
    'Unsaved changes will be lost. Do you want to proceed?' => 'Има незапазени промени, наистина ли искате да напуснете тази страница?',
    'Unsubscribe' => 'Отписване',
    'Upload' => 'Качване',
    'Upload file' => 'Качи файл',
    'You are not allowed to run this action.' => 'Нямате право да изпълнявате това действие.',
    '{nFormatted}B' => '{nFormatted}B',
    '{nFormatted}K' => '{nFormatted}K',
    '{nFormatted}M' => '{nFormatted}M',
    'Allow content from external source' => '',
    'Always allow content from this provider!' => '',
    'An unexpected error occurred. Please check whether your file exceeds the allowed upload limit of {maxUploadSize}.' => '',
    'Back to login' => '',
    'Do you want to enable content from \'{urlPrefix}\'?' => '',
    'I\'m not a robot' => '',
    'My Profile' => '',
    'No results' => '',
    'Search...' => '',
    'Show all results' => '',
    'Stop impersonation' => '',
    'Switch network' => '',
    'Verified' => '',
    'We couldn\'t verify that you\'re human. Please check the box again.' => '',
    'verify your upload_max_filesize and post_max_size php settings.' => '',
    '{attribute} has been empty. The system-configured function to fill empty values has returned an invalid value. Please try again or contact your administrator.' => '',
    '{attribute} must be a string (UUID) or null; {type} given.' => '',
    '{attribute} must be an UUID or null. UUID has the format "{{XXXXXXXX-XXXX-XXXX-XXXX-XXXXXXXXXXXX}}", where X = [a-fA-F0-9] and both curly brackets and delimiting dashes are optional.' => '',
];
